// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QVARIANTHASH_H
#define QVARIANTHASH_H

#if 0
#pragma qt_class(QVariantHash)
#endif

#include <QtCore/qglobal.h>

#include <QtCore/QHash>
#include <QtCore/QVariant>
#include <QtCore/QString>

QT_BEGIN_NAMESPACE
QT_END_NAMESPACE

#endif
