// Copyright (C) 2016 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QTGUIGLOBAL_H
#define QTGUIGLOBAL_H

#include <QtCore/qglobal.h>
#include <QtGui/qtgui-config.h>
#include <QtGui/qtguiexports.h>

#endif // QTGUIGLOBAL_H
